@@ -1,5 +1,5 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
+ * 
  * Copyright (C) 2003-2004 Bastien Nocera <hadess@hadess.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,14 +17,16 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * Authors: Bastien Nocera <hadess@hadess.net>
+ *
  */
 
 #include <glib.h>
 #include <string.h>
 #include "nautilus-burn-drive.h"
 
-static char*
-add_desc (char *string, const char *addition)
+static char *
+add_desc (char       *string,
+	  const char *addition)
 {
 	char *new;
 
@@ -37,7 +39,7 @@ add_desc (char *string, const char *addition)
 	return new;
 }
 
-static char*
+static char *
 drive_type (int type)
 {
 	char *string;
@@ -49,6 +51,9 @@ drive_type (int type)
 	if (type & NAUTILUS_BURN_DRIVE_TYPE_CD_RECORDER) {
 		string = add_desc (string, "CD Recorder");
 	}
+	if (type & NAUTILUS_BURN_DRIVE_TYPE_CDRW_RECORDER) {
+		string = add_desc (string, "CD ReWritable");
+	}
 	if (type & NAUTILUS_BURN_DRIVE_TYPE_DVD_RAM_RECORDER) {
 		string = add_desc (string, "DVD-RAM");
 	}
@@ -71,85 +76,77 @@ drive_type (int type)
 	return string;
 }
 
-static const char*
-media_type_get_string (int type)
-{
-	switch (type) {
-	case NAUTILUS_BURN_MEDIA_TYPE_BUSY:
-		return "Unknown media, CD drive is busy";
-	case NAUTILUS_BURN_MEDIA_TYPE_ERROR:
-		return "Couldn't open media";
-	case NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN:
-		return "Unknown Media";
-	case NAUTILUS_BURN_MEDIA_TYPE_CD:
-		return "Commercial CD or Audio CD";
-	case NAUTILUS_BURN_MEDIA_TYPE_CDR:
-		return "CD-R";
-	case NAUTILUS_BURN_MEDIA_TYPE_CDRW:
-		return "CD-RW";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVD:
-		return "DVD";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVDR:
-		return "DVD-R, or DVD-RAM";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVDRW:
-		return "DVD-RW";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVD_RAM:
-		return "DVD-RAM";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R:
-		return "DVD+R";
-	case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_RW:
-		return "DVD+RW";
-	}
-
-	return "Broken media type";
-}
-
 static void
-list_cdroms (void)
+list_drives (void)
 {
-	GList *cdroms, *l;
-	NautilusBurnDrive *cd;
+	GList             *drives, *l;
+	NautilusBurnDrive *drive;
 
-	cdroms = nautilus_burn_drive_get_list (FALSE, FALSE);
+	drives = nautilus_burn_drive_get_list (FALSE, FALSE);
 
-	for (l = cdroms; l != NULL; l = l->next)
-	{
-		char *type_str;
+	for (l = drives; l != NULL; l = l->next) {
+		char       *type_str;
 		const char *media;
-		int media_type;
-		gboolean is_rewritable;
-		gint64 size;
+		int         media_type;
+		gboolean    is_rewritable;
+		gboolean    is_blank;
+		gboolean    has_data;
+		gboolean    has_audio;
+		gboolean    door_is_open;
+		gint64      size;
 
-		cd = l->data;
-		type_str = drive_type (cd->type);
-		media_type = nautilus_burn_drive_get_media_type_and_rewritable (cd, &is_rewritable);
-		media = media_type_get_string (media_type);
+		drive = l->data;
+		type_str = drive_type (drive->type);
+		media_type = nautilus_burn_drive_get_media_type_full (drive,
+								      &is_rewritable,
+								      &is_blank,
+								      &has_data,
+								      &has_audio);
+		media = nautilus_burn_drive_media_type_get_string (media_type);
+
+		door_is_open = nautilus_burn_drive_door_is_open (drive);
 
 		g_print ("name: %s device: %s max_speed_read: %d\n",
-				cd->display_name, cd->device,
-				cd->max_speed_read);
+			 drive->display_name,
+			 drive->device,
+			 drive->max_speed_read);
+		g_print ("door: %s\n", door_is_open ? "open" : "closed");
 		g_print ("type: %s\n", type_str);
-		g_print ("media type: %s%s\n", media, is_rewritable?" (rewritable)":"");
-		size = nautilus_burn_drive_get_media_size (cd);
-		g_print ("media size: %0.2f megs", (float) size / 1024 / 1024);
-		if (media_type == NAUTILUS_BURN_MEDIA_TYPE_CDR || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDRW) {
-			g_print ("approx. or %d mins %d secs)\n", SIZE_TO_TIME(size) / 60, SIZE_TO_TIME(size) % 60);
+		g_print ("media type: %s%s%s%s%s\n",
+			 media,
+			 is_rewritable ? " (rewritable)" : "",
+			 is_blank ? " (blank)" : "",
+			 has_data ? " (has-data)" : "",
+			 has_audio ? " (has-audio)" : "");
+
+		size = nautilus_burn_drive_get_media_size (drive);
+		g_print ("media size: %0.2f MiB", (float) size / 1024 / 1024);
+
+		if (media_type == NAUTILUS_BURN_MEDIA_TYPE_CD
+		    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDR
+		    || media_type == NAUTILUS_BURN_MEDIA_TYPE_CDRW) {
+			g_print (" approx. or %d mins %d secs\n",
+				 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) / 60,
+				 NAUTILUS_BURN_DRIVE_SIZE_TO_TIME (size) % 60);
 		} else {
 			g_print ("\n");
 		}
+
 		g_print ("CD-Recorder/SCSI devices only: max_speed_write: %d"
-				" id: %s\n", cd->max_speed_write,
-				cd->cdrecord_id);
+			 " id: %s\n", drive->max_speed_write,
+			 drive->cdrecord_id);
 		g_print ("\n");
+
 		g_free (type_str);
-		nautilus_burn_drive_free (cd);
+		nautilus_burn_drive_free (drive);
 	}
-	g_list_free (cdroms);
+
+	g_list_free (drives);
 }
 
 int main (int argc, char **argv)
 {
-	list_cdroms ();
+	list_drives ();
 
 	return 0;
 }
