@@ -747,11 +747,15 @@ nautilus_burn_drive_hal_get_media_type_full (NautilusBurnDrive *drive,
 			if (dbus_error_is_set (&error)) {
 				g_warning ("%s\n", error.message);
 				dbus_error_free (&error);
+				libhal_free_string_array (device_names);
+
 				return NAUTILUS_BURN_MEDIA_TYPE_ERROR;
 			}
 
 			if (num_devices == 0) {
 				g_warning ("No HAL devices found for UDI '%s'", drive->priv->udi);
+				libhal_free_string_array (device_names);
+
 				return NAUTILUS_BURN_MEDIA_TYPE_ERROR;
 			}
 
@@ -2376,7 +2380,7 @@ nautilus_burn_drive_media_type_get_string (NautilusBurnMediaType type)
 {
 	switch (type) {
 	case NAUTILUS_BURN_MEDIA_TYPE_BUSY:
-		return _("Unknown media, CD drive is busy");
+		return _("Could not determine media type because CD drive is busy");
 	case NAUTILUS_BURN_MEDIA_TYPE_ERROR:
 		return _("Couldn't open media");
 	case NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN:
