@@ -1,8 +1,9 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
  *
- * cd-drive.h: easy to use cd burner software
+ * nautilus-burn-drive.h: easy to use cd burner software
  *
  * Copyright (C) 2002-2004 Red Hat, Inc.
+ * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +22,7 @@
  *
  * Authors: Alexander Larsson <alexl@redhat.com>
  *          Bastien Nocera <hadess@hadess.net>
+ *          William Jon McCann <mccann@jhu.edu>
  */
 
 #ifndef NAUTILUS_BURN_DRIVE_H
@@ -43,6 +45,7 @@ typedef enum {
 	NAUTILUS_BURN_MEDIA_TYPE_DVD_RAM,
 	NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R,
 	NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_RW,
+	NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R_DL,
 } NautilusBurnMediaType;
 
 #define NAUTILUS_BURN_MEDIA_SIZE_UNKNOWN -1
@@ -74,12 +77,15 @@ typedef struct {
 	NautilusBurnDrivePriv *priv;
 } NautilusBurnDrive;
 
-#define SIZE_TO_TIME(size) (size > 0 ? (int) (((size / 1024 / 1024) - 1) * 48 / 7): 0)
+#define NAUTILUS_BURN_DRIVE_SIZE_TO_TIME(size) (size > 0 ? (int) (((size / 1024 / 1024) - 1) * 48 / 7): 0)
 
 GList *               nautilus_burn_drive_get_list                 (gboolean                 recorder_only,
 								    gboolean                 add_image);
 
 NautilusBurnDrive *   nautilus_burn_drive_new                      (void);
+NautilusBurnDrive *   nautilus_burn_drive_new_from_path            (const char              *device_path);
+NautilusBurnDrive *   nautilus_burn_drive_get_file_image           (void);
+
 void                  nautilus_burn_drive_free                     (NautilusBurnDrive       *drive);
 
 gboolean              nautilus_burn_drive_equal                    (NautilusBurnDrive       *a,
@@ -88,9 +94,6 @@ gboolean              nautilus_burn_drive_equal                    (NautilusBurn
 NautilusBurnDrive *   nautilus_burn_drive_copy                     (NautilusBurnDrive       *drive);
 NautilusBurnMediaType nautilus_burn_drive_get_media_type           (NautilusBurnDrive       *drive);
 
-NautilusBurnMediaType nautilus_burn_drive_get_media_type_and_rewritable 
-                                                                   (NautilusBurnDrive       *drive,
-								    gboolean                *is_rewritable);
 NautilusBurnMediaType nautilus_burn_drive_get_media_type_full      (NautilusBurnDrive       *drive,
 								    gboolean                *is_rewritable,
 								    gboolean                *is_blank,
@@ -99,13 +102,17 @@ NautilusBurnMediaType nautilus_burn_drive_get_media_type_full      (NautilusBurn
 NautilusBurnMediaType nautilus_burn_drive_get_media_type_from_path (const char              *device_path);
 gint64                nautilus_burn_drive_get_media_size           (NautilusBurnDrive       *drive);
 gint64                nautilus_burn_drive_get_media_size_from_path (const char              *device_path);
-NautilusBurnDrive *   nautilus_burn_drive_get_file_image           (void);
 
 gboolean              nautilus_burn_drive_lock                     (NautilusBurnDrive       *drive,
 								    const char              *reason,
 								    char                   **reason_for_failure);
 gboolean              nautilus_burn_drive_unlock                   (NautilusBurnDrive       *drive);
 gboolean              nautilus_burn_drive_unmount                  (NautilusBurnDrive       *drive);
+gboolean              nautilus_burn_drive_eject                    (NautilusBurnDrive       *drive);
+
+gboolean              nautilus_burn_drive_door_is_open             (NautilusBurnDrive       *drive);
+
+const char *          nautilus_burn_drive_media_type_get_string    (NautilusBurnMediaType    type);
 
 G_END_DECLS
 
