@@ -344,6 +344,8 @@ nautilus_burn_progress_temp_files_cleanup (void)
 			g_unlink (filename);
 		}
 
+		g_free (filename);
+
 		files_for_cleanup = g_list_remove (files_for_cleanup, files_for_cleanup->data);
 	}
 }
@@ -1189,7 +1191,7 @@ burn_cd (const NautilusBurnDrive *drive,
 	} else {
 		if (source_iso == NULL) {
 			GConfClient *gc;
-			const char  *path;
+			char        *path;
 
 			gc = gconf_client_get_default ();
 			path = gconf_client_get_string (gc, "/apps/nautilus-cd-burner/temp_iso_dir", NULL);
@@ -1199,6 +1201,8 @@ burn_cd (const NautilusBurnDrive *drive,
 				fd = g_mkstemp (filename);
 				close (fd);
 			}
+
+			g_free (path);
 		} else {
 			filename = g_strdup (source_iso);
 		}
@@ -2075,7 +2079,7 @@ create_selection_dialog (NautilusBurnerSourceData *burn_data)
 
 	cursor = gdk_cursor_new (GDK_WATCH);
 	gdk_window_set_cursor (dialog->window, cursor);
-	gdk_cursor_destroy (cursor);
+	gdk_cursor_unref (cursor);
 
 	g_signal_connect (dialog, "response", G_CALLBACK (selection_dialog_response), burn_data);
 
